
EMBEDDING_MODEL_NOMIC = "nomic-embed-text"
EMBEDDING_MODEL_MINILM = "all-minilm"

MODEL_PHI3 = "phi3"
MODEL_LLAMA3 = "llama3"

DEFAULT_MODEL = MODEL_PHI3
DEFAULT_EMBEDDING_MODEL = EMBEDDING_MODEL_NOMIC

